@@ -249,9 +249,7 @@ static const gchar *ui_info =
 "    </menu>"
 "    <menu action='ViewMenu'>"
 "      <menuitem action='Toolbar'/>"
-"        <separator/>"
 "      <menuitem action='Spending'/>"
-"        <separator/>"
 "      <menuitem action='Upcoming'/>"
 "        <separator/>"
 "      <menuitem action='AsMinor'/>"
@@ -362,11 +360,10 @@ gint result;
 	if( result == 1)
 	{
 		DB( g_print(" - should revert\n") );
-		hbfile_change_filepath(homebank_filepath_with_extention(GLOBALS->xhb_filepath, "xhb~"));
-
+		
+		hbfile_change_filepath(hb_filename_new_with_extention(GLOBALS->xhb_filepath, "xhb~"));
 		ui_mainwindow_open_internal(widget, NULL);
-
-		//todo: error here after, we must set the filename bak to .xhb
+		hbfile_change_filepath(hb_filename_new_with_extention(GLOBALS->xhb_filepath, "xhb"));
 
 	}
 
@@ -549,8 +546,7 @@ gint result;
 		GTK_WINDOW(GLOBALS->mainwindow),
 		_("Anonymize the file ?"),
 		_("Proceeding will changes name/memo to anonymous datas,\n"
-		"please confirm."),
-		NULL
+		"please confirm.")
 		);
 
 	if( result == GTK_RESPONSE_NO )
@@ -765,10 +761,13 @@ static void ui_mainwindow_action_about(void)
 
 static void ui_mainwindow_action_export(void)
 {
-	test_qif_export();
+gchar *filename;
 
-
-	//create_import_window();
+	if( ui_file_chooser_qif(NULL, &filename) == TRUE )
+	{
+		hb_export_qif_account_all(filename);
+		g_free( filename );
+	}
 }
 
 static void ui_mainwindow_action_help(void)
@@ -944,14 +943,14 @@ static void ui_mainwindow_selection(GtkTreeSelection *treeselection, gpointer us
 
 static void ui_mainwindow_close_openbooks(void)
 {
-GList *list;
+GList *lacc, *elt;
 
 	DB( g_print("\n[ui-mainwindow] close openbooks\n") );
 
-	list = g_hash_table_get_values(GLOBALS->h_acc);
-	while (list != NULL)
+	lacc = elt = g_hash_table_get_values(GLOBALS->h_acc);
+	while (elt != NULL)
 	{
-	Account *item = list->data;
+	Account *item = elt->data;
 
 		if(item->window)
 		{
@@ -959,9 +958,9 @@ GList *list;
 			item->window = NULL;
 		}
 
-		list = g_list_next(list);
+		elt = g_list_next(elt);
 	}
-	g_list_free(list);
+	g_list_free(lacc);
 
 }
 
@@ -1387,6 +1386,12 @@ gint usermode = GPOINTER_TO_INT(user_data);
 	{
 	gchar *txt;
 
+		//#125534
+		if( count > 0 )
+		{
+			ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_REFRESHALL));
+		}
+		
 		if(count == 0)
 			txt = _("No transaction to add");
 		else
@@ -1525,7 +1530,6 @@ gint r = XML_UNSET;
 			homebank_file_ensure_xhb();
 			r = homebank_save_xml(GLOBALS->xhb_filepath);
 			GLOBALS->hbfile_is_new = FALSE;
-
 		}
 		else
 			return;
@@ -1565,7 +1569,7 @@ void ui_mainwindow_populate_accounts(GtkWidget *widget, gpointer user_data)
 struct hbfile_data *data;
 GtkTreeModel *model;
 GtkTreeIter  iter1, child_iter;
-GList *list;
+GList *lacc, *elt;
 Account *acc;
 guint i, j, nbtype;
 gdouble gtbank, gttoday, gtfuture;
@@ -1577,10 +1581,10 @@ gdouble gtbank, gttoday, gtfuture;
 	/* here we create a count and a list of every account pointer by type */
 
 	GPtrArray *typeacc[ACC_TYPE_MAXVALUE] = {0};
-	list = g_hash_table_get_values(GLOBALS->h_acc);
-	while (list != NULL)
+	lacc = elt = g_hash_table_get_values(GLOBALS->h_acc);
+	while (elt != NULL)
 	{
-		acc = list->data;
+		acc = elt->data;
 		if( !(acc->flags & (AF_CLOSED|AF_NOREPORT|AF_NOSUMMARY)) )
 		{
 			DB( g_print(" -> insert %d:%s\n", acc->key, acc->name) );
@@ -1590,9 +1594,9 @@ gdouble gtbank, gttoday, gtfuture;
 
 			g_ptr_array_add(typeacc[acc->type], (gpointer)acc);
 		}
-		list = g_list_next(list);
+		elt = g_list_next(elt);
 	}
-	g_list_free(list);
+	g_list_free(lacc);
 
 	gtbank = gttoday = gtfuture = 0;
 
