@@ -609,6 +609,7 @@ gchar **str_array;
 	return retval;
 }
 
+
 guint32 hb_date_get_julian(gchar *string, gint datefmt)
 {
 GDate *date;
@@ -668,6 +669,56 @@ guint32 julian = 0;
 }
 
 
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =*/
+
+
+gchar *hb_filename_new_with_extention(gchar *filename, const gchar *extension)
+{
+gchar *dirname;
+gchar *basename;
+gchar *newbasename;
+gchar *newfilename;
+gchar **str_array;
+
+	dirname  = g_path_get_dirname (filename);
+	basename = g_path_get_basename(filename);
+	str_array = g_strsplit(basename, ".", 0);
+	newbasename = g_strdup_printf("%s.%s", str_array[0], extension);
+	newfilename = g_build_filename(dirname, newbasename, NULL);
+
+	g_strfreev(str_array);
+	g_free(basename);
+	g_free(dirname);
+	g_free(newbasename);
+
+	return newfilename;
+}
+
+
+/* file backup, qif export */
+
+
+/*gchar *homebank_filename_without_extention(gchar *path)
+{
+gchar *basename;
+gchar *newname;
+gchar **str_array;
+
+	basename = g_path_get_basename(path);
+
+	str_array = g_strsplit(basename, ".", 0);
+
+	newname = g_strdup(str_array[0]);
+
+	g_strfreev(str_array);
+	g_free(basename);
+
+	return newname;
+}*/
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =*/
+
+
 static gboolean hb_string_isdate(gchar *str)
 {
 gint d, m, y;
